#!/bin/bash

set -euE -o pipefail

cleanup=()
_do_cleanup() {
	if [[ $? == 0 ]]; then
		echo ":: Cleaning up..."
	else
		echo >&2 "!! ERROR! Cleaning up..."
	fi
	for (( i=${#cleanup[@]}-1; i >= 0; i-- )); do
		eval "${cleanup[$i]}"
	done
}
trap '_do_cleanup' EXIT

set -x

################################################################################

outfile="${0##*/}"
outfile="${outfile%.sh}.img"

rm -f "$outfile"

################################################################################

truncate --size=2G "$outfile"

parted --script "$outfile" \
     mklabel msdos \
     mkpart primary ext4 1M 100% \
     set 1 boot on

loopdev=$(sudo losetup --find --show --partscan -- "$outfile")
cleanup+=("sudo losetup --detach ${loopdev@Q}")

sudo mkfs.ext4 -F -O ^metadata_csum,^64bit "${loopdev}p1"

mountpoint=$(mktemp -dt "${0##*/}.XXXXXXXXXX")
cleanup+=("rm -rf -- ${mountpoint@Q}")
sudo mount "${loopdev}p1" "$mountpoint"
cleanup+=("sudo umount ${mountpoint@Q}")

./bin/osi-mk \
	--conf=format=dir --conf=bootloader=none --edit \
	--conf=arch=armv7h \
	--package=base \
	--package=linux-libre \
	--package=uboot4extlinux-orangepi_one \
	--module=../modules/umorpha-sshusers.sh \
	--module=../modules/base-net.sh \
	"$mountpoint"

# XXX
sudo install -m644 \
     /home/lukeshu/packages/abslibre/libre/uboot4extlinux-sunxi/pkg/uboot4extlinux-orangepi_one/usr/lib/u-boot/uboot4extlinux-orangepi_one/u-boot-sunxi-with-spl.bin \
     "$mountpoint"/usr/lib/u-boot/uboot4extlinux-orangepi_one/u-boot-sunxi-with-spl.bin

sudo arch-chroot "$mountpoint" \
     /usr/lib/u-boot/uboot4extlinux-orangepi_one/install-uboot4extlinux.sh "$loopdev"
sudo arch-chroot "$mountpoint" \
     install -Dm644 /usr/lib/u-boot/uboot4extlinux-sunxi/extlinux.conf /boot/extlinux/extlinux.conf
for pkgbasefile in "$mountpoint"/usr/lib/modules/*/pkgbase; do
	pkgbase="$(cat "$pkgbasefile")"
	sudo install "${pkgbasefile%pkgbase}vmlinuz" "$mountpoint/boot/vmlinuz-$pkgbase"
done
